==> haskell-yesod-static-1.6.1.0-931-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-AlcgGBUEJyBL2g3TS75d3v
key:                  yesod-static-1.6.1.0-AlcgGBUEJyBL2g3TS75d3v
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  21112d60065398153762cc366a7ba538
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-static
hs-libraries:         HSyesod-static-1.6.1.0-AlcgGBUEJyBL2g3TS75d3v
depends:
    async-2.2.5-DWviBtrYTc7K8qRxzPsJC
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW base-4.17.2.1
    base64-bytestring-1.2.1.0-Fa0BuK0N9mu9JPJP7gaxRT
    blaze-builder-0.4.4-1ntb6RP4OewIlLWEkSeIAR bytestring-0.11.5.3
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1 containers-0.6.7
    cryptonite-0.30-J05HlVSc5IIHLQ8uVby8as
    cryptonite-conduit-0.2.2-JHAmE9kjgZHEnkENauO34p
    css-text-0.1.3.0-FECKdKwLgPJLoNdEve82f
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    hjsmin-0.2.1-82lJeiSNTHz7mY4b12t3NO
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq process-1.6.18.0
    template-haskell-2.19.0.0 text-2.0.2 transformers-0.5.6.2
    unix-compat-0.7.4.1-E7DsEjXAuRTILEPpVPaZJi
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    wai-3.2.4-LnpkwzoHUW9G2cGUC0nKUm
    wai-app-static-3.1.9-Glm2Lw7sTGQFOpqdgiTlrW
    yesod-core-1.6.27.1-KFoprkJXhJa2ewlge46soy

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.6.1.0-961-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-IDviG1bbzV92U8Ge1vfKLV
key:                  yesod-static-1.6.1.0-IDviG1bbzV92U8Ge1vfKLV
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  a1f4990d43084b34c2c3e92c5a11d968
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-static
hs-libraries:         HSyesod-static-1.6.1.0-IDviG1bbzV92U8Ge1vfKLV
depends:
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    base64-bytestring-1.2.1.0-G8BjkxE58WI1uqeVjCB0n4
    blaze-builder-0.4.4.1-1AsqmJqbexUDW45IoYp4gz bytestring-0.11.5.3
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3 containers-0.6.7
    cryptonite-0.30-5T9hA5iejCiIzteqbNsY1m
    cryptonite-conduit-0.2.2-EHEwFq1tz3PCAANf4d8iFw
    css-text-0.1.3.0-1mZeY7sQKBjEWRJIEp8LeT
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    hjsmin-0.2.1-GuhCTEDLsVO59FzJLo8ni3
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq process-1.6.18.0
    template-haskell-2.19.0.0 text-2.0.2 transformers-0.5.6.2
    unix-compat-0.7.4.1-4GSEG4F7IBa3tepmzc9c8r
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    wai-3.2.4-GKgviHtnWhO3KoBTtmAmpl
    wai-app-static-3.1.9-HQN6tAEXe3G2u36LT6d9l9
    yesod-core-1.6.27.1-EwsliX2Eq0V3h6VQF9toZp

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
